@@ -1,4 +1,4 @@
-// Copyright © 2016 Daniele Tricoli <eriol@mornie.org>.
+// Copyright © 2016-2017 Daniele Tricoli <eriol@mornie.org>.
 // All rights reserved.
 // Use of this source code is governed by a BSD-style
 // license that can be found in the LICENSE file.
@@ -37,10 +37,10 @@
 //! }
 //! ```
 
-#![feature(custom_derive, plugin)]
-#![plugin(serde_macros)]
+#[macro_use]
+extern crate serde_derive;
 
-extern crate hyper;
+extern crate reqwest;
 extern crate serde;
 extern crate serde_json;
 extern crate url;
